Skip to contents

Uses latitude and longitude points to select grid id values

Usage

grid_select(data)

Arguments

data

a dataframe that includes at least the parameters latitude and longitude in decimal degrees

Value

Returns the dataframe with an additional column of index values

Examples