R/grid_select.R
grid_select.Rd
Uses latitude and longitude points to select grid id values
grid_select(data)
a dataframe that includes at least the parameters latitude and longitude in decimal degrees
Returns the dataframe with an additional column of index values